@@ -55,6 +55,7 @@ import re
 import sys
 import traceback
 
+MAXINT = 1000000
 
 S_IP_ADDRESS = lambda x, token: ['ip_address', token]
 S_WORD = lambda x, token:  ['word', token]
@@ -478,14 +479,14 @@ def trim_docstring(docstring):
     # and split into a list of lines:
     lines = docstring.expandtabs().splitlines()
     # Determine minimum indentation (first line doesn't count):
-    indent = sys.maxint
+    indent = MAXINT
     for line in lines[1:]:
         stripped = line.lstrip()
         if stripped:
             indent = min(indent, len(line) - len(stripped))
     # Remove indentation (first line is special):
     trimmed = [lines[0].strip()]
-    if indent < sys.maxint:
+    if indent < MAXINT:
         for line in lines[1:]:
             trimmed.append(line[indent:].rstrip())
     # Strip off trailing and leading blank lines:
